@@ -70,6 +70,14 @@ class Serializable:
         return cls.__init__(**kwargs)
 
 
+class DatabaseTypeToUse(Enum):
+    none = "none"
+    existing = "existing"
+    managed = "managed"
+    filebased = "filebased"
+    from_script = "from_script"
+
+
 class CromwellConfiguration(Serializable):
     """
     Based on information provided by: https://github.com/broadinstitute/cromwell/blob/develop/cromwell.examples.conf
@@ -217,6 +225,7 @@ class CromwellConfiguration(Serializable):
                 password=None,
                 num_threads=None,
                 maxConnections=None,
+                numThreads=8,
             ):
                 self.driver = driver
                 self.url = url
@@ -225,6 +234,7 @@ class CromwellConfiguration(Serializable):
                 self.connectionTimeout = connection_timeout
                 self.num_threads = num_threads
                 self.maxConnections = maxConnections
+                self.numThreads = numThreads
 
         def __init__(self, profile=None, insert_batch_size=None, db: Db = None):
             self.db = db
@@ -290,7 +300,10 @@ hsqldb.script_format=3
                             hashing_strategy=None,
                             check_sibling_md5=None,
                         ):
-                            self.duplication_strategy = duplication_strategy or [""]
+                            self.duplication_strategy = (
+                                duplication_strategy
+                                or CromwellConfiguration.DEFAULT_LOCALIZATION_STRATEGY
+                            )
                             self.hashing_strategy = hashing_strategy
                             self.check_sibling_md5 = check_sibling_md5
 
@@ -394,11 +407,6 @@ hsqldb.script_format=3
                 call_caching_method: str = None,
                 sbatch: str = "sbatch",
             ):
-
-                afternotokaycommand = ""
-                if afternotokaycatch:
-                    afternotokaycommand = f" && NTOKDEP=$({sbatch} --parsable --kill-on-invalid-dep=yes --dependency=afternotokay:$JOBID --wrap '{CromwellConfiguration.CATCH_ERROR_COMMAND}')"
-
                 emailextra = (
                     f'--mail-user "{jobemail}" --mail-type END' if jobemail else ""
                 )
@@ -417,6 +425,10 @@ hsqldb.script_format=3
                     else:
                         partition_string = '${"-p" + queue}'
 
+                afternotokaycommand = ""
+                if afternotokaycatch:
+                    afternotokaycommand = f" && NTOKDEP=$({sbatch} --parsable --job-name \"catch-$jobname\" --kill-on-invalid-dep=yes {partition_string} --time '0:60' --dependency=afternotokay:$JOBID --wrap '{CromwellConfiguration.CATCH_ERROR_COMMAND}')"
+
                 return cls(
                     actor_factory="cromwell.backend.impl.sfs.config.ConfigBackendLifecycleActorFactory",
                     config=cls.Config(
@@ -445,6 +457,7 @@ JOBID=$({sbatch} \\
     && echo Submitted batch job $JOBID
 """,
                         kill="scancel ${job_id}",
+                        kill_docker="scancel ${job_id}",
                         check_alive="scontrol show job ${job_id}",
                         job_id_regex="Submitted batch job (\\d+).*",
                         filesystems=cls.Config.Filesystem.default_filesystem(
@@ -473,10 +486,6 @@ JOBID=$({sbatch} \\
                     sbatch=sbatch,
                 )
 
-                afternotokaycommand = ""
-                if afternotokaycatch:
-                    afternotokaycommand = f" && NTOKDEP=$({sbatch} --parsable --kill-on-invalid-dep=yes --dependency=afternotokay:$JOBID --wrap '{CromwellConfiguration.CATCH_ERROR_COMMAND}')"
-
                 partition_string = ""
                 if jobqueues:
                     partitions = (
@@ -491,6 +500,10 @@ JOBID=$({sbatch} \\
                     else:
                         partition_string = '${"-p" + queue}'
 
+                afternotokaycommand = ""
+                if afternotokaycatch:
+                    afternotokaycommand = f" && NTOKDEP=$({sbatch} --parsable --job-name \"catch-$jobname\" --kill-on-invalid-dep=yes {partition_string} --time '0:60' --dependency=afternotokay:$JOBID --wrap '{CromwellConfiguration.CATCH_ERROR_COMMAND}')"
+
                 emailextra = (
                     f'--mail-user "{jobemail}" --mail-type END' if jobemail else ""
                 )
@@ -601,8 +614,8 @@ JOBID=$({sbatch} \\
     jobname={CromwellConfiguration.JOBNAME_TRANSFORM}
     walltime='00:00:${{duration}}'
 
-    JOBID=$(echo "/usr/bin/env ${{job_shell}} ${{script}}" \\
-        | qsub \\
+    JOBID=$(echo "/usr/bin/env ${{job_shell}} ${{script}}" | \\
+        qsub \\
             -V \\
             -d ${{cwd}} \\
             -N $jobname \\
@@ -679,8 +692,8 @@ JOBID=$({sbatch} \\
 
     JOBID=$(echo \\
         "{loadinstructions} \\
-        singularity exec --bind ${{cwd}}:${{docker_cwd}} $image ${{job_shell}} ${{docker_script}}" \\
-        | qsub \\
+        singularity exec --bind ${{cwd}}:${{docker_cwd}} $image ${{job_shell}} ${{docker_script}}" | \\
+        qsub \\
             -v ${{cwd}} \\
             -N $jobname \\
             {emailparams} \\
@@ -842,7 +855,7 @@ JOBID=$({sbatch} \\
                 db_flush_rate: Optional[int] = None,
             ):
                 """
-                
+
                 :param summary_refresh_interval: Set this value to "Inf" to turn off metadata summary refresh.  The default value is currently "1 second"
                 :param summary_refresh_limit: maximum number of metadata rows to be considered per summarization cycle
                 :param db_batch_size:
