@@ -312,7 +312,8 @@ class CWLTool(Engine):
                 run_id=run_id,
                 id_=key,
                 is_copyable=True,
-                original_path=out["path"],
+                value=out["path"],
+                original_path=None,
                 timestamp=DateUtil.now(),
                 new_path=None,
                 output_folder=None,
@@ -328,7 +329,8 @@ class CWLTool(Engine):
                     submission_id=None,
                     run_id=run_id,
                     id_=newk,
-                    original_path=path,
+                    value=path,
+                    original_path=None,
                     is_copyable=True,
                     timestamp=DateUtil.now(),
                     new_path=None,
