@@ -126,7 +126,13 @@ def translate(
         valuesfromrecipe = jc.recipes.get_recipe_for_keys(recipes)
         inputsdict.update(valuesfromrecipe)
 
-    inputsdict.update(cascade_inputs(wf=None, inputs=inputs, required_inputs=None,))
+    inputsdict.update(
+        cascade_inputs(
+            wf=None,
+            inputs=inputs,
+            required_inputs=None,
+        )
+    )
 
     if isinstance(toolref, DynamicWorkflow):
         if not inputsdict:
@@ -402,6 +408,7 @@ def fromjanis(
     watch=True,
     max_cores=None,
     max_memory=None,
+    max_duration=None,
     force=False,
     keep_intermediate_files=False,
     recipes=None,
@@ -518,6 +525,7 @@ def fromjanis(
             watch=watch,
             max_cores=max_cores,
             max_memory=max_memory,
+            max_duration=max_duration,
             keep_intermediate_files=keep_intermediate_files,
             run_in_background=should_run_in_background,
             dbconfig=dbconfig,
@@ -599,7 +607,7 @@ def abort_wids(sids: List[str]):
     for sid in sids:
         try:
             row = ConfigManager.manager().get_row_for_submission_id_or_path(sid)
-            WorkflowManager.mark_aborted(row.execution_dir, row.output_dir)
+            WorkflowManager.mark_aborted(row.execution_dir, row.submission_id)
         except Exception as e:
             Logger.critical(f"Couldn't abort '{sid}': " + str(e))
             raise e
