@@ -85,7 +85,7 @@ class ConfigManager:
         tm = WorkflowManager.from_path_with_submission_id(
             task.outputdir, task.submission_id
         )
-        tm.remove_exec_dir_if_required()
+        tm.cleanup_execution()
         tm.database.close()
 
         if not keep_output and os.path.exists(task.outputdir):
@@ -198,6 +198,7 @@ class ConfigManager:
         watch=True,
         max_cores=None,
         max_memory=None,
+        max_duration=None,
         keep_intermediate_files=False,
         run_in_background=True,
         dbconfig=None,
@@ -221,6 +222,7 @@ class ConfigManager:
             watch=watch,
             max_cores=max_cores,
             max_memory=max_memory,
+            max_duration=max_duration,
             keep_intermediate_files=keep_intermediate_files,
             run_in_background=run_in_background,
             dbconfig=dbconfig,
