@@ -622,7 +622,7 @@ class JanisDatabaseConfigurationHelper:
             username=None, password=None, url=url
         )
 
-    def get_config_for_template_supplied(self, output_dir: str):
+    def get_config_for_template_supplied(self, execution_dir: str):
         try:
             import subprocess, os, json
             from janis_assistant.management.envvariables import EnvVariables
@@ -638,12 +638,12 @@ class JanisDatabaseConfigurationHelper:
                 raise Exception(
                     f"Couldn't get database credentials as couldn't find value in env var '{EnvVariables.db_script_generator}'"
                 )
-            if not os.path.exists(file_path):
-                raise Exception(f"Couldn't locate script '{file_path}' to execute")
+            # if not os.path.exists(file_path):
+            #     raise Exception(f"Couldn't locate script '{file_path}' to execute")
 
             try:
                 val = collect_output_from_command(
-                    [file_path, output_dir], stderr=Logger.guess_log
+                    f"{file_path} {execution_dir}", stderr=Logger.guess_log, shell=True
                 )
             except Exception as e:
                 Logger.critical(f"Failed to generate database credentials ({repr(e)})")
@@ -687,11 +687,11 @@ class JanisDatabaseConfigurationHelper:
             Logger.debug(
                 f"Found path '{EnvVariables.db_script_generator_cleanup}' to delete database credentials"
             )
-            if not os.path.exists(file_path):
-                raise Exception(f"Couldn't locate script '{file_path}' to execute")
+            # if not os.path.exists(file_path):
+            #     raise Exception(f"Couldn't locate script '{file_path}' to execute")
 
             val = collect_output_from_command(
-                [file_path, execution_dir], stderr=Logger.guess_log
+                f"{file_path} {execution_dir}", stderr=Logger.guess_log, shell=True
             )
             if val is not None and len(val) > 0:
                 Logger.info(
