@@ -14,6 +14,7 @@ class PbsSingularityTemplate(SingularityEnvironmentTemplate):
         "singularity_load_instructions",
         "max_cores",
         "max_ram",
+        "max_duration",
         "intermediate_execution_dir",
     ]
 
@@ -29,6 +30,7 @@ class PbsSingularityTemplate(SingularityEnvironmentTemplate):
         singularity_load_instructions=None,
         max_cores=None,
         max_ram=None,
+        max_duration=None,
         can_run_in_foreground=True,
         run_in_background=False,
     ):
@@ -42,6 +44,7 @@ class PbsSingularityTemplate(SingularityEnvironmentTemplate):
         :param singularity_load_instructions: Ensure singularity with this command executed in shell
         :param max_cores: Maximum number of cores a task can request
         :param max_ram: Maximum amount of ram (GB) that a task can request
+        :param max_duration: Maximum amount of time in seconds (s) that a task can request
         """
 
         super().__init__(
@@ -51,6 +54,7 @@ class PbsSingularityTemplate(SingularityEnvironmentTemplate):
             load_instructions=singularity_load_instructions,
             max_cores=max_cores,
             max_ram=max_ram,
+            max_duration=max_duration,
             can_run_in_foreground=can_run_in_foreground,
             run_in_background=run_in_background,
         )
@@ -85,9 +89,9 @@ class PbsSingularityTemplate(SingularityEnvironmentTemplate):
             ),
         )
 
-        beconfig: CromwellConfiguration.Backend.Provider.Config = config.backend.providers[
-            config.backend.default
-        ].config
+        beconfig: CromwellConfiguration.Backend.Provider.Config = (
+            config.backend.providers[config.backend.default].config
+        )
         if self.intermediate_execution_dir:
             beconfig.root = self.intermediate_execution_dir
 
